@@ -55,6 +55,7 @@ int main(int argc, char *argv[])
     }
     Cmd->AddArcName(ModuleName);
     Cmd->ParseDone();
+    Cmd->AbsoluteLinks=true; // If users runs SFX, he trusts an archive source.
 #else // !SFX_MODULE
     Cmd->ParseCommandLine(true,argc,argv);
     if (!Cmd->ConfigDisabled)
@@ -70,10 +71,9 @@ int main(int argc, char *argv[])
 #endif
 
     uiInit(Cmd->Sound);
-    InitConsoleOptions(Cmd->MsgStream);
+    InitConsoleOptions(Cmd->MsgStream,Cmd->RedirectCharset);
     InitLogOptions(Cmd->LogName,Cmd->ErrlogCharset);
     ErrHandler.SetSilent(Cmd->AllYes || Cmd->MsgStream==MSG_NULL);
-    ErrHandler.SetShutdown(Cmd->Shutdown);
 
     Cmd->OutTitle();
     Cmd->ProcessCommand();
@@ -94,7 +94,7 @@ int main(int argc, char *argv[])
   }
 
 #if defined(_WIN_ALL) && !defined(SFX_MODULE) && !defined(SHELL_EXT)
-  if (ShutdownOnClose)
+  if (ShutdownOnClose && ErrHandler.IsShutdownEnabled())
     Shutdown();
 #endif
   ErrHandler.MainExit=true;
